@@ -1,15 +1,18 @@
 import http
+import json
 import logging
-
 import math
 import time
+
 from fastapi import Request, Response
-from starlette.middleware.base import RequestResponseEndpoint, BaseHTTPMiddleware, DispatchFunction
+from starlette.middleware.base import BaseHTTPMiddleware, DispatchFunction, RequestResponseEndpoint
 from starlette.types import ASGIApp
-from py_fastapi_logging.middlewares.utils.request_id import generate_request_id, REQUEST_ID_HEADER
+
+from py_fastapi_logging.config.config import LogConfigure, init_logger
+from py_fastapi_logging.middlewares.utils.request_id import REQUEST_ID_HEADER, generate_request_id
 from py_fastapi_logging.schemas.request import RequestPayload
 from py_fastapi_logging.schemas.response import ResponsePayload
-from py_fastapi_logging.config.config import init_logger, LogConfigure
+from py_fastapi_logging.utils.extra import set_extra_to_environ
 
 
 class LoggingMiddleware(BaseHTTPMiddleware):
@@ -25,10 +28,13 @@ class LoggingMiddleware(BaseHTTPMiddleware):
         prefix: str = None,
         logger: logging.Logger = None,
     ):
+        if not logger:
+            init_logger(app_name=app_name)
+            logger = logging.getLogger("default")
         self.app = app
         self._app_name = app_name
         self._prefix = prefix
-        self._logger = logger if logger else init_logger(LogConfigure(app_name=app_name))
+        self._logger = logger
         self.dispatch_func = self.dispatch if dispatch is None else dispatch
 
     @staticmethod
@@ -72,6 +78,7 @@ class LoggingMiddleware(BaseHTTPMiddleware):
             request_body = ""
         request_headers: dict = dict(request.headers.items())
         request_id = self.get_request_id_header(request_headers) or generate_request_id(prefix=self._prefix)
+        set_extra_to_environ("request_id", request_id)
 
         server: tuple = request.get("server", ("localhost", 80))
         request_params = request.query_params
@@ -102,7 +109,7 @@ class LoggingMiddleware(BaseHTTPMiddleware):
             method=request.method,
             path=request.url.path,
             host=f"{server[0]}:{server[1]}",
-            params=request_params,
+            params=dict(request_params),
             body=request_body,
         )
 
@@ -116,7 +123,7 @@ class LoggingMiddleware(BaseHTTPMiddleware):
 
         extra_fields = {
             "tags": ["API", "REQUEST"],
-            "payload": request_log_payload.dict(),
+            "payload": self._filter_private_data(request_log_payload),
             "to_mask": True,
             "progname": self._app_name,
             "request_id": request_id,
@@ -129,11 +136,35 @@ class LoggingMiddleware(BaseHTTPMiddleware):
         )
 
         extra_fields["tags"] = ["API", "RESPONSE"]
-        extra_fields["payload"] = response_log_payload.dict()
+        extra_fields["payload"] = self._filter_private_data(response_log_payload)
 
         logger_method(
             f"RESPONSE {response.status_code} {request.url.path}",
             extra=extra_fields,
             exc_info=exception_object,
         )
+
         return response
+
+    def _filter_private_data(self, payload: dict):
+        _filtered_fields = LogConfigure().get_exclude_fields()
+        _marker_filtered = "[filtered]"
+        if "params" in payload.keys():
+            for key in list(payload["params"]):
+                if key in _filtered_fields:
+                    payload["params"][key] = _marker_filtered
+            payload = self._filter_json_field("body", payload, _filtered_fields, _marker_filtered)
+        elif "response_body" in payload.keys():
+            payload = self._filter_json_field("response_body", payload, _filtered_fields, _marker_filtered)
+        return payload
+
+    def _filter_json_field(self, key, payload, _filtered_fields, _marker_filtered="[filtered]"):
+        try:
+            body_dict = json.loads(payload[key])
+            for key in list(body_dict):
+                if key in _filtered_fields:
+                    body_dict[key] = _marker_filtered
+            payload[key] = json.dumps(body_dict)
+        except json.decoder.JSONDecodeError:
+            pass
+        return payload
